@@ -9,11 +9,11 @@ import pandas as pd
 import unyts
 
 
-__version__ = '0.1.4'
-__release__ = 20230220
+__version__ = '0.1.6'
+__release__ = 20230223
 __all__ = ['Log']
 
-logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
+logging.basicConfig(level=logging.INFO)
 
 
 class Log2FrameType(type):
@@ -151,11 +151,11 @@ class Log(object, metaclass=Log2FrameType):
         if isinstance(index_units, Log):
             index_units = index_units.index_units
         if hasattr(self.data, 'index_to'):
-            data = self.data.index_to(index_units)
-            if data.index.units == index_units:
+            if hasattr(self.data.index, 'units') and self.data.index.units == index_units:
                 logging.info("index units are already '" + str(index_units) + "'.")
                 return self
-            elif data.index.units == self.data.index.units:
+            data = self.data.index_to(index_units)
+            if data.index.units == self.data.index.units:
                 logging.warning("index units not converted!")
                 units = self.units
             else:
